@@ -1,33 +1,23 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import
-from __future__ import division
 import json
 import math
-import fiona
-from fiona.errors import DriverError
-import rasterio
 import warnings
-from rasterio.transform import guard_transform
-from rasterio.enums import MaskFlags
-from affine import Affine
+from collections.abc import Iterable, Mapping
+from json import JSONDecodeError
+
+import fiona
 import numpy as np
-from shapely import wkt, wkb
+import rasterio
+from affine import Affine
+from fiona.errors import DriverError
+from rasterio.enums import MaskFlags
+from rasterio.transform import guard_transform
+from shapely import wkb, wkt
 
 try:
     from shapely.errors import ShapelyError
 except ImportError:  # pragma: no cover
     from shapely.errors import ReadingError as ShapelyError
 
-try:
-    from json.decoder import JSONDecodeError
-except ImportError:  # pragma: no cover
-    JSONDecodeError = ValueError
-
-try:
-    from collections.abc import Iterable, Mapping
-except ImportError:  # pragma: no cover
-    from collections import Iterable, Mapping
-
 
 geom_types = [
     "Point",
@@ -38,6 +28,21 @@ geom_types = [
     "MultiPolygon",
 ]
 
+try:
+    # Fiona 1.9+
+    import fiona.model
+
+    def fiona_generator(obj, layer=0):
+        with fiona.open(obj, "r", layer=layer) as src:
+            for feat in src:
+                yield fiona.model.to_dict(feat)
+
+except ModuleNotFoundError:
+    # Fiona <1.9
+    def fiona_generator(obj, layer=0):
+        with fiona.open(obj, "r", layer=layer) as src:
+            yield from src
+
 
 def wrap_geom(geom):
     """Wraps a geometry dict in an GeoJSON Feature"""
@@ -91,20 +96,8 @@ def read_features(obj, layer=0):
             with fiona.open(obj, "r", layer=layer) as src:
                 assert len(src) > 0
 
-            def fiona_generator(obj):
-                with fiona.open(obj, "r", layer=layer) as src:
-                    for feature in src:
-                        yield feature
-
-            features_iter = fiona_generator(obj)
-        except (
-            AssertionError,
-            TypeError,
-            IOError,
-            OSError,
-            DriverError,
-            UnicodeDecodeError,
-        ):
+            features_iter = fiona_generator(obj, layer)
+        except (AssertionError, TypeError, OSError, DriverError, UnicodeDecodeError):
             try:
                 mapping = json.loads(obj)
                 if "type" in mapping and mapping["type"] == "FeatureCollection":
@@ -229,7 +222,7 @@ class NodataWarning(UserWarning):
 already_warned_nodata = False
 
 
-class Raster(object):
+class Raster:
     """Raster abstraction for data access to 2/3D array-like things
 
     Use as a context manager to ensure dataset gets closed properly::
@@ -284,7 +277,7 @@ class Raster(object):
 
     def index(self, x, y):
         """Given (x, y) in crs, return the (row, column) on the raster"""
-        col, row = [math.floor(a) for a in (~self.affine * (x, y))]
+        col, row = (math.floor(a) for a in (~self.affine * (x, y)))
         return row, col
 
     def read(self, bounds=None, window=None, masked=False, boundless=True):
