@@ -1,17 +1,18 @@
 # test zonal stats
 import json
 import os
-import pytest
-import simplejson
 import sys
 
 import numpy as np
+import pytest
 import rasterio
-from rasterstats import zonal_stats, raster_stats
-from rasterstats.utils import VALID_STATS
-from rasterstats.io import read_featurecollection, read_features
-from shapely.geometry import Polygon
+import simplejson
 from affine import Affine
+from shapely.geometry import Polygon
+
+from rasterstats import raster_stats, zonal_stats
+from rasterstats.io import read_featurecollection, read_features
+from rasterstats.utils import VALID_STATS
 
 sys.path.append(os.path.dirname(os.path.abspath(__file__)))
 
@@ -65,7 +66,7 @@ def test_nonsense():
     polygons = os.path.join(DATA, "polygons.shp")
     with pytest.raises(ValueError):
         zonal_stats("blaghrlargh", raster)
-    with pytest.raises(IOError):
+    with pytest.raises(OSError):
         zonal_stats(polygons, "blercherlerch")
     with pytest.raises(ValueError):
         zonal_stats(
@@ -257,9 +258,9 @@ def _assert_dict_eq(a, b):
             continue
         try:
             if abs(a[k] - b[k]) > err:
-                raise AssertionError("{}: {} != {}".format(k, a[k], b[k]))
+                raise AssertionError(f"{k}: {a[k]} != {b[k]}")
         except TypeError:  # can't take abs, nan
-            raise AssertionError("{} != {}".format(a[k], b[k]))
+            raise AssertionError(f"{a[k]} != {b[k]}")
 
 
 def test_ndarray():
